==> tabular-data-template-1.2.1-20140430.150703-2-sources.jar: org/gcube/portlets/user/tdtemplate/client/resources/TdTemplateAbstractResources.java <==
/**
 * 
 */
package org.gcube.portlets.user.tdtemplate.client.resources;

import com.google.gwt.core.client.GWT;
import com.google.gwt.user.client.ui.AbstractImagePrototype;

/**
 * @author Francesco Mangiacrapa francesco.mangiacrapa@isti.cnr.it
 * @Jan 10, 2014
 *
 */
public class TdTemplateAbstractResources {

	
	public static final ResourcesTemplate INSTANCE = GWT.create(ResourcesTemplate.class);
	
	public static AbstractImagePrototype columnAdd(){
		return AbstractImagePrototype.create(INSTANCE.getAddColumn());
	}
	
	public static AbstractImagePrototype columnRemove(){
		return AbstractImagePrototype.create(INSTANCE.getRemoveColumn());
	}
	
	public static AbstractImagePrototype columnModify(){
		return AbstractImagePrototype.create(INSTANCE.getModifyColumn());
	}
	
	public static AbstractImagePrototype dataType(){
		return AbstractImagePrototype.create(INSTANCE.pencil());
	}
	
	public static AbstractImagePrototype pencil10(){
		return AbstractImagePrototype.create(INSTANCE.pencil10());
	}
	
	public static AbstractImagePrototype delete(){
		return AbstractImagePrototype.create(INSTANCE.delete());
	}
	
	public static AbstractImagePrototype suggest(){
		return AbstractImagePrototype.create(INSTANCE.suggest());
	}
	
	public static AbstractImagePrototype handsUP(){
		return AbstractImagePrototype.create(INSTANCE.handsup());
	}
	
	public static AbstractImagePrototype submit(){
		return AbstractImagePrototype.create(INSTANCE.submit());
	}
	
	public static AbstractImagePrototype newtemplate(){
		return AbstractImagePrototype.create(INSTANCE.newtemplate());
	}
	
	public static AbstractImagePrototype error(){
		return AbstractImagePrototype.create(INSTANCE.error());
	}
	
	public static AbstractImagePrototype okicon(){
		return AbstractImagePrototype.create(INSTANCE.okicon());
	}
	
	public static AbstractImagePrototype alerticon(){
		return AbstractImagePrototype.create(INSTANCE.alerticon());
	}
	
	public static AbstractImagePrototype info(){
		return AbstractImagePrototype.create(INSTANCE.info());
	}
	
	public static AbstractImagePrototype lock(){
		return AbstractImagePrototype.create(INSTANCE.lock());
	}

	/**
	 * @return
	 */
	public static AbstractImagePrototype tip() {
		return AbstractImagePrototype.create(INSTANCE.tip());
	}
	
	/**
	 * @return
	 */
	public static AbstractImagePrototype loader() {
		return AbstractImagePrototype.create(INSTANCE.loader());
	}
	
	/**
	 * @return
	 */
	public static AbstractImagePrototype step1() {
		return AbstractImagePrototype.create(INSTANCE.step1());
	}
	
	/**
	 * @return
	 */
	public static AbstractImagePrototype step2() {
		return AbstractImagePrototype.create(INSTANCE.step2());
	}
	
	/**
	 * @return
	 */
	public static AbstractImagePrototype step3() {
		return AbstractImagePrototype.create(INSTANCE.step3());
	}
	
	/**
	 * @return
	 */
	public static AbstractImagePrototype filter16() {
		return AbstractImagePrototype.create(INSTANCE.filter16());
	}
	
	/**
	 * @return
	 */
	public static AbstractImagePrototype filter24() {
		return AbstractImagePrototype.create(INSTANCE.filter24());
	}
}

==> tabular-data-template-1.3.0-20140520.140504-2-sources.jar: org/gcube/portlets/user/tdtemplate/client/resources/TdTemplateAbstractResources.java <==
/**
 * 
 */
package org.gcube.portlets.user.tdtemplate.client.resources;

import com.google.gwt.core.client.GWT;
import com.google.gwt.user.client.ui.AbstractImagePrototype;

/**
 * @author Francesco Mangiacrapa francesco.mangiacrapa@isti.cnr.it
 * @Jan 10, 2014
 *
 */
public class TdTemplateAbstractResources {

	
	public static final ResourcesTemplate INSTANCE = GWT.create(ResourcesTemplate.class);
	
	public static AbstractImagePrototype columnAdd(){
		return AbstractImagePrototype.create(INSTANCE.getAddColumn());
	}
	
	public static AbstractImagePrototype columnRemove(){
		return AbstractImagePrototype.create(INSTANCE.getRemoveColumn());
	}
	
	public static AbstractImagePrototype columnModify(){
		return AbstractImagePrototype.create(INSTANCE.getModifyColumn());
	}
	
	public static AbstractImagePrototype pencil(){
		return AbstractImagePrototype.create(INSTANCE.pencil());
	}
	
	public static AbstractImagePrototype addRule(){
		return AbstractImagePrototype.create(INSTANCE.rule());
	}
	
	public static AbstractImagePrototype pencil10(){
		return AbstractImagePrototype.create(INSTANCE.pencil10());
	}
	
	public static AbstractImagePrototype delete(){
		return AbstractImagePrototype.create(INSTANCE.delete());
	}
	
	public static AbstractImagePrototype suggest(){
		return AbstractImagePrototype.create(INSTANCE.suggest());
	}
	
	public static AbstractImagePrototype handsUP(){
		return AbstractImagePrototype.create(INSTANCE.handsup());
	}
	
	public static AbstractImagePrototype submit(){
		return AbstractImagePrototype.create(INSTANCE.submit());
	}
	
	public static AbstractImagePrototype newtemplate(){
		return AbstractImagePrototype.create(INSTANCE.newtemplate());
	}
	
	public static AbstractImagePrototype error(){
		return AbstractImagePrototype.create(INSTANCE.error());
	}
	
	public static AbstractImagePrototype okicon(){
		return AbstractImagePrototype.create(INSTANCE.okicon());
	}
	
	public static AbstractImagePrototype alerticon(){
		return AbstractImagePrototype.create(INSTANCE.alerticon());
	}
	
	public static AbstractImagePrototype info(){
		return AbstractImagePrototype.create(INSTANCE.info());
	}
	
	public static AbstractImagePrototype lock(){
		return AbstractImagePrototype.create(INSTANCE.lock());
	}

	/**
	 * @return
	 */
	public static AbstractImagePrototype tip() {
		return AbstractImagePrototype.create(INSTANCE.tip());
	}
	
	/**
	 * @return
	 */
	public static AbstractImagePrototype loader() {
		return AbstractImagePrototype.create(INSTANCE.loader());
	}
	
	/**
	 * @return
	 */
	public static AbstractImagePrototype step1() {
		return AbstractImagePrototype.create(INSTANCE.step1());
	}
	
	/**
	 * @return
	 */
	public static AbstractImagePrototype step2() {
		return AbstractImagePrototype.create(INSTANCE.step2());
	}
	
	/**
	 * @return
	 */
	public static AbstractImagePrototype step3() {
		return AbstractImagePrototype.create(INSTANCE.step3());
	}
	
	/**
	 * @return
	 */
	public static AbstractImagePrototype filter16() {
		return AbstractImagePrototype.create(INSTANCE.filter16());
	}
	
	/**
	 * @return
	 */
	public static AbstractImagePrototype filter24() {
		return AbstractImagePrototype.create(INSTANCE.filter24());
	}
}
